@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -59,6 +59,8 @@ int ARKStepSetMaxStep(void *arkode_mem, realtype hmax) {
   return(arkSetMaxStep(arkode_mem, hmax)); }
 int ARKStepSetStopTime(void *arkode_mem, realtype tstop) {
   return(arkSetStopTime(arkode_mem, tstop)); }
+int ARKStepClearStopTime(void *arkode_mem) {
+  return(arkClearStopTime(arkode_mem)); }
 int ARKStepSetRootDirection(void *arkode_mem, int *rootdir) {
   return(arkSetRootDirection(arkode_mem, rootdir)); }
 int ARKStepSetNoInactiveRootWarn(void *arkode_mem) {
