@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -569,14 +569,27 @@ int erkStep_Init(void* arkode_mem, int init_type)
     ark_mem->liw += (step_mem->stages + 1);   /* pointers */
   }
 
-  /* Limit interpolant degree based on method order (use negative
-     argument to specify update instead of overwrite) */
-  if (ark_mem->interp != NULL) {
-    retval = arkInterpSetDegree(ark_mem, ark_mem->interp, -(step_mem->q-1));
-    if (retval != ARK_SUCCESS) {
+  /* Limit max interpolant degree (negative input only overwrites the current
+     interpolant degree if it is greater than abs(input). */
+  if (ark_mem->interp != NULL)
+  {
+    if (step_mem->q > 1)
+    {
+      /* Limit max degree to at most one less than the method global order */
+      retval = arkInterpSetDegree(ark_mem, ark_mem->interp, -(step_mem->q - 1));
+    }
+    else
+    {
+      /* Allow for linear interpolant with first order methods to ensure
+         solution values are returned at the time interval end points */
+      retval = arkInterpSetDegree(ark_mem, ark_mem->interp, -(step_mem->q));
+    }
+
+    if (retval != ARK_SUCCESS)
+    {
       arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ERKStep", "erkStep_Init",
                       "Unable to update interpolation polynomial degree");
-      return(ARK_ILL_INPUT);
+      return (ARK_ILL_INPUT);
     }
   }
 
@@ -753,11 +766,15 @@ int erkStep_TakeStep(void* arkode_mem, realtype *dsmPtr, int *nflagPtr)
                      ark_mem->nst, ark_mem->h, ark_mem->tcur);
 #endif
 
-#ifdef SUNDIALS_DEBUG_PRINTVEC
-  printf("    ERKStep stage 0 solution:\n");
-  N_VPrint(ark_mem->ycur);
-  printf("    ERKStep stage RHS F[0]:\n");
-  N_VPrint(step_mem->F[0]);
+#ifdef SUNDIALS_LOGGING_EXTRA_DEBUG
+  SUNLogger_QueueMsg(ARK_LOGGER, SUN_LOGLEVEL_DEBUG,
+                     "ARKODE::erkStep_TakeStep", "stage",
+                     "z[0] =", "");
+  N_VPrintFile(ark_mem->ycur, ARK_LOGGER->debug_fp);
+  SUNLogger_QueueMsg(ARK_LOGGER, SUN_LOGLEVEL_DEBUG,
+                     "ARKODE::erkStep_TakeStep", "stage RHS",
+                     "F[0] =", "");
+  N_VPrintFile(step_mem->F[0], ARK_LOGGER->debug_fp);
 #endif
 
   /* Loop over internal stages to the step; since the method is explicit
@@ -809,9 +826,11 @@ int erkStep_TakeStep(void* arkode_mem, realtype *dsmPtr, int *nflagPtr)
     if (retval < 0)  return(ARK_RHSFUNC_FAIL);
     if (retval > 0)  return(ARK_UNREC_RHSFUNC_ERR);
 
-#ifdef SUNDIALS_DEBUG_PRINTVEC
-    printf("    ERKStep stage RHS F[%i]:\n",is);
-    N_VPrint(step_mem->F[is]);
+#ifdef SUNDIALS_LOGGING_EXTRA_DEBUG
+    SUNLogger_QueueMsg(ARK_LOGGER, SUN_LOGLEVEL_DEBUG,
+                       "ARKODE::erkStep_TakeStep", "stage RHS",
+                       "F[%i] =", is);
+    N_VPrintFile(step_mem->F[is], ARK_LOGGER->debug_fp);
 #endif
 
   } /* loop over stages */
@@ -820,12 +839,11 @@ int erkStep_TakeStep(void* arkode_mem, realtype *dsmPtr, int *nflagPtr)
   retval = erkStep_ComputeSolutions(ark_mem, dsmPtr);
   if (retval < 0)  return(retval);
 
-#ifdef SUNDIALS_DEBUG
-  printf("    ERKStep error estimate = %"RSYM"\n", *dsmPtr);
-#endif
-#ifdef SUNDIALS_DEBUG_PRINTVEC
-  printf("    ERKStep updated solution:\n");
-  N_VPrint(ark_mem->ycur);
+#ifdef SUNDIALS_LOGGING_EXTRA_DEBUG
+  SUNLogger_QueueMsg(ARK_LOGGER, SUN_LOGLEVEL_DEBUG,
+                     "ARKODE::erkStep_TakeStep", "updated solution",
+                     "ycur =", "");
+  N_VPrintFile(ark_mem->ycur, ARK_LOGGER->debug_fp);
 #endif
 
   /* Solver diagnostics reporting */
