@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -59,6 +59,8 @@ int ERKStepSetMaxStep(void *arkode_mem, realtype hmax) {
   return(arkSetMaxStep(arkode_mem, hmax)); }
 int ERKStepSetStopTime(void *arkode_mem, realtype tstop) {
   return(arkSetStopTime(arkode_mem, tstop)); }
+int ERKStepClearStopTime(void *arkode_mem) {
+  return(arkClearStopTime(arkode_mem)); }
 int ERKStepSetRootDirection(void *arkode_mem, int *rootdir) {
   return(arkSetRootDirection(arkode_mem, rootdir)); }
 int ERKStepSetNoInactiveRootWarn(void *arkode_mem) {
@@ -305,7 +307,7 @@ int ERKStepSetTable(void *arkode_mem, ARKodeButcherTable B)
   based on the integer flag passed to ARKodeButcherTable_LoadERK()
   within the file arkode_butcher_erk.c.
   ---------------------------------------------------------------*/
-int ERKStepSetTableNum(void *arkode_mem, ARKODE_ERKTableID itable)
+int ERKStepSetTableNum(void *arkode_mem, ARKODE_ERKTableID etable)
 {
   ARKodeMem ark_mem;
   ARKodeERKStepMem step_mem;
@@ -318,7 +320,7 @@ int ERKStepSetTableNum(void *arkode_mem, ARKODE_ERKTableID itable)
   if (retval != ARK_SUCCESS) return(retval);
 
   /* check that argument specifies an explicit table */
-  if (itable<ARKODE_MIN_ERK_NUM || itable>ARKODE_MAX_ERK_NUM) {
+  if (etable<ARKODE_MIN_ERK_NUM || etable>ARKODE_MAX_ERK_NUM) {
     arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE::ERKStep",
                     "ERKStepSetTableNum",
                     "Illegal ERK table number");
@@ -337,7 +339,7 @@ int ERKStepSetTableNum(void *arkode_mem, ARKODE_ERKTableID itable)
   ark_mem->lrw -= Blrw;
 
   /* fill in table based on argument */
-  step_mem->B = ARKodeButcherTable_LoadERK(itable);
+  step_mem->B = ARKodeButcherTable_LoadERK(etable);
   if (step_mem->B == NULL) {
     arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE::ERKStep",
                     "ERKStepSetTableNum",
@@ -355,6 +357,18 @@ int ERKStepSetTableNum(void *arkode_mem, ARKODE_ERKTableID itable)
   return(ARK_SUCCESS);
 }
 
+/*---------------------------------------------------------------
+  ERKStepSetTableName:
+
+  Specifies to use a pre-existing Butcher table for the problem,
+  based on the string passed to ARKodeButcherTable_LoadERKByNmae()
+  within the file arkode_butcher_erk.c.
+  ---------------------------------------------------------------*/
+int ERKStepSetTableName(void *arkode_mem, const char *etable)
+{
+  return ERKStepSetTableNum(arkode_mem,
+                            arkButcherTableERKNameToID(etable));
+}
 
 /*===============================================================
   ERKStep optional output functions -- stepper-specific
