@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -12,9 +12,9 @@
  * SUNDIALS Copyright End
  *---------------------------------------------------------------
  * This is the implementation file for the optional input and
- * output functions for the ARKode infrastructure; these routines
+ * output functions for the ARKODE infrastructure; these routines
  * should not be called directly by the user; instead they are
- * provided as utility routines for ARKode time-step modules
+ * provided as utility routines for ARKODE time-step modules
  * to use.
  *--------------------------------------------------------------*/
 
@@ -28,13 +28,13 @@
 
 
 /*===============================================================
-  ARKode optional input utility functions
+  ARKODE optional input utility functions
   ===============================================================*/
 
 /*---------------------------------------------------------------
   arkSetDefaults:
 
-  Resets all optional inputs to ARKode default values.  Does not
+  Resets all optional inputs to ARKODE default values.  Does not
   change problem-defining function pointers fe and fi or
   user_data pointer.  Also leaves alone any data
   structures/options related to root-finding (those can be reset
@@ -44,7 +44,7 @@ int arkSetDefaults(void *arkode_mem)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetDefaults", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -126,7 +126,7 @@ int arkSetInterpolantType(void *arkode_mem, int itype)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetInterpolantType", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -134,7 +134,7 @@ int arkSetInterpolantType(void *arkode_mem, int itype)
 
   /* check for legal itype input */
   if ((itype != ARK_INTERP_HERMITE) && (itype != ARK_INTERP_LAGRANGE)) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetInterpolantType",
                     "Illegal interpolation type input.");
     return(ARK_ILL_INPUT);
@@ -142,7 +142,7 @@ int arkSetInterpolantType(void *arkode_mem, int itype)
 
   /* do not change type once the module has been initialized */
   if (ark_mem->initialized) {
-    arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKode",
+    arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKODE",
                     "arkSetInterpolantType",
                     "Type cannot be specified after module initialization.");
     return(ARK_ILL_INPUT);
@@ -162,7 +162,7 @@ int arkSetInterpolantType(void *arkode_mem, int itype)
     ark_mem->interp = arkInterpCreate_Lagrange(arkode_mem, ARK_INTERP_MAX_DEGREE);
   }
   if (ark_mem->interp == NULL) {
-    arkProcessError(ark_mem, ARK_MEM_FAIL, "ARKode", "arkSetInterpolantType",
+    arkProcessError(ark_mem, ARK_MEM_FAIL, "ARKODE", "arkSetInterpolantType",
                     "Unable to allocate interpolation structure");
     return(ARK_MEM_FAIL);
   }
@@ -189,14 +189,14 @@ int arkSetInterpolantDegree(void *arkode_mem, int degree)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetInterpolantDegree", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
   ark_mem = (ARKodeMem) arkode_mem;
 
   if (ark_mem->interp == NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE",
                     "arkSetInterpolantDegree",
                     "Interpolation module is not yet allocated");
     return(ARK_MEM_NULL);
@@ -204,7 +204,7 @@ int arkSetInterpolantDegree(void *arkode_mem, int degree)
 
   /* do not change degree once the module has been initialized */
   if (ark_mem->initialized) {
-    arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKode",
+    arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKODE",
                     "arkSetInterpolantType",
                     "Degree cannot be specified after module initialization.");
     return(ARK_ILL_INPUT);
@@ -225,7 +225,7 @@ int arkSetErrHandlerFn(void *arkode_mem, ARKErrHandlerFn ehfun,
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetErrHandlerFn", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -253,7 +253,7 @@ int arkSetErrFile(void *arkode_mem, FILE *errfp)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetErrFile", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -272,7 +272,7 @@ int arkSetUserData(void *arkode_mem, void *user_data)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetUserData", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -309,7 +309,7 @@ int arkSetDiagnostics(void *arkode_mem, FILE *diagfp)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetDiagnostics", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -334,7 +334,7 @@ int arkSetMaxNumSteps(void *arkode_mem, long int mxsteps)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMaxNumSteps", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -359,7 +359,7 @@ int arkSetMaxHnilWarns(void *arkode_mem, int mxhnil)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMaxHnilWarns", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -385,7 +385,7 @@ int arkSetInitStep(void *arkode_mem, realtype hin)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetInitStep", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -420,7 +420,7 @@ int arkSetMinStep(void *arkode_mem, realtype hmin)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMinStep", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -434,7 +434,7 @@ int arkSetMinStep(void *arkode_mem, realtype hmin)
 
   /* check that hmin and hmax are agreeable */
   if (hmin * ark_mem->hmax_inv > ONE) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetMinStep", MSG_ARK_BAD_HMIN_HMAX);
     return(ARK_ILL_INPUT);
   }
@@ -456,7 +456,7 @@ int arkSetMaxStep(void *arkode_mem, realtype hmax)
   realtype hmax_inv;
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMaxStep", MSG_ARK_NO_MEM);
     return (ARK_MEM_NULL);
   }
@@ -471,7 +471,7 @@ int arkSetMaxStep(void *arkode_mem, realtype hmax)
   /* check that hmax and hmin are agreeable */
   hmax_inv = ONE/hmax;
   if (hmax_inv * ark_mem->hmin > ONE) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetMaxStep", MSG_ARK_BAD_HMIN_HMAX);
     return(ARK_ILL_INPUT);
   }
@@ -492,19 +492,19 @@ int arkSetStopTime(void *arkode_mem, realtype tstop)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetStopTime", MSG_ARK_NO_MEM);
     return (ARK_MEM_NULL);
   }
   ark_mem = (ARKodeMem) arkode_mem;
 
-  /* If ARKode was called at least once, test if tstop is legal
+  /* If ARKODE was called at least once, test if tstop is legal
      (i.e. if it was not already passed).
-     If arkSetStopTime is called before the first call to ARKode,
-     tstop will be checked in ARKode. */
+     If arkSetStopTime is called before the first call to ARKODE,
+     tstop will be checked in ARKODE. */
   if (ark_mem->nst > 0) {
     if ( (tstop - ark_mem->tcur) * ark_mem->h < ZERO ) {
-      arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+      arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                       "arkSetStopTime", MSG_ARK_BAD_TSTOP,
                       tstop, ark_mem->tcur);
       return(ARK_ILL_INPUT);
@@ -518,14 +518,35 @@ int arkSetStopTime(void *arkode_mem, realtype tstop)
 }
 
 
+/*---------------------------------------------------------------
+  arkClearStopTime:
+
+  Disable the stop time.
+  ---------------------------------------------------------------*/
+int arkClearStopTime(void *arkode_mem)
+{
+  ARKodeMem ark_mem;
+  if (arkode_mem==NULL) {
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
+                    "arkClearStopTime", MSG_ARK_NO_MEM);
+    return (ARK_MEM_NULL);
+  }
+  ark_mem = (ARKodeMem) arkode_mem;
+
+  ark_mem->tstopset = SUNFALSE;
+
+  return(ARK_SUCCESS);
+}
+
+
 /*---------------------------------------------------------------
   arkSetFixedStep:
 
   Specifies to use a fixed time step size instead of performing
-  any form of temporal adaptivity.  ARKode will use this step size
+  any form of temporal adaptivity.  ARKODE will use this step size
   for all steps (unless tstop is set, in which case it may need to
   modify that last step approaching tstop.  If any solver failure
-  occurs in the timestepping module, ARKode will typically
+  occurs in the timestepping module, ARKODE will typically
   immediately return with an error message indicating that the
   selected step size cannot be used.
 
@@ -537,7 +558,7 @@ int arkSetFixedStep(void *arkode_mem, realtype hfixed)
   int retval;
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetFixedStep", MSG_ARK_NO_MEM);
     return (ARK_MEM_NULL);
   }
@@ -577,20 +598,20 @@ int arkSetRootDirection(void *arkode_mem, int *rootdir)
   int i;
 
   if (arkode_mem == NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetRootDirection", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
   ark_mem = (ARKodeMem) arkode_mem;
   if (ark_mem->root_mem == NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE",
                     "arkSetRootDirection", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
   ark_root_mem = (ARKodeRootMem) ark_mem->root_mem;
 
   if (ark_root_mem->nrtfn == 0) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetRootDirection", MSG_ARK_NO_ROOT);
     return(ARK_ILL_INPUT);
   }
@@ -611,13 +632,13 @@ int arkSetNoInactiveRootWarn(void *arkode_mem)
   ARKodeMem ark_mem;
   ARKodeRootMem ark_root_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetNoInactiveRootWarn", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
   ark_mem = (ARKodeMem) arkode_mem;
   if (ark_mem->root_mem == NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE",
                     "arkSetNoInactiveRootWarn", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -643,7 +664,7 @@ int arkSetPostprocessStepFn(void *arkode_mem,
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetPostprocessStepFn", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -680,7 +701,7 @@ int arkSetPostprocessStageFn(void *arkode_mem,
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetPostprocessStageFn", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -703,7 +724,7 @@ int arkSetConstraints(void *arkode_mem, N_Vector constraints)
   realtype temptest;
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetConstraints", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -722,7 +743,7 @@ int arkSetConstraints(void *arkode_mem, N_Vector constraints)
       constraints->ops->nvcompare     == NULL ||
       constraints->ops->nvconstrmask  == NULL ||
       constraints->ops->nvminquotient == NULL) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "ARKStepSetConstraints", MSG_ARK_BAD_NVECTOR);
     return(ARK_ILL_INPUT);
   }
@@ -730,7 +751,7 @@ int arkSetConstraints(void *arkode_mem, N_Vector constraints)
   /* Check the constraints vector */
   temptest = N_VMaxNorm(constraints);
   if ((temptest > RCONST(2.5)) || (temptest < HALF)) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "ARKStepSetConstraints", MSG_ARK_BAD_CONSTR);
     return(ARK_ILL_INPUT);
   }
@@ -757,7 +778,7 @@ int arkSetMaxNumConstrFails(void *arkode_mem, int maxfails)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMaxNumConstrFails", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -792,7 +813,7 @@ int arkSetCFLFraction(void *arkode_mem, realtype cfl_frac)
 
   /* check for allowable parameters */
   if (cfl_frac >= ONE) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetCFLFraction", "Illegal CFL fraction");
     return(ARK_ILL_INPUT);
   }
@@ -827,7 +848,7 @@ int arkSetSafetyFactor(void *arkode_mem, realtype safety)
 
   /* check for allowable parameters */
   if (safety >= ONE) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetSafetyFactor", "Illegal safety factor");
     return(ARK_ILL_INPUT);
   }
@@ -974,7 +995,7 @@ int arkSetAdaptivityMethod(void *arkode_mem, int imethod, int idefault,
 
   /* check for allowable parameters */
   if ((imethod > ARK_ADAPT_IMEX_GUS) || (imethod < ARK_ADAPT_PID)) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkSetAdaptivityMethod", "Illegal imethod");
     return(ARK_ILL_INPUT);
   }
@@ -1195,7 +1216,7 @@ int arkSetMaxErrTestFails(void *arkode_mem, int maxnef)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMaxErrTestFails", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1222,7 +1243,7 @@ int arkSetMaxConvFails(void *arkode_mem, int maxncf)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetMaxConvFails", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1240,7 +1261,7 @@ int arkSetMaxConvFails(void *arkode_mem, int maxncf)
 
 
 /*===============================================================
-  ARKode optional output utility functions
+  ARKODE optional output utility functions
   ===============================================================*/
 
 /*---------------------------------------------------------------
@@ -1252,7 +1273,7 @@ int arkGetNumStepAttempts(void *arkode_mem, long int *nstep_attempts)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumStepAttempts", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1272,7 +1293,7 @@ int arkGetNumSteps(void *arkode_mem, long int *nsteps)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumSteps", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1292,7 +1313,7 @@ int arkGetActualInitStep(void *arkode_mem, realtype *hinused)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetActualInitStep", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1312,7 +1333,7 @@ int arkGetLastStep(void *arkode_mem, realtype *hlast)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetLastStep", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1332,7 +1353,7 @@ int arkGetCurrentStep(void *arkode_mem, realtype *hcur)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetCurrentStep", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1353,7 +1374,7 @@ int arkGetCurrentState(void *arkode_mem, N_Vector *state)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetCurrentState", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1373,7 +1394,7 @@ int arkGetCurrentTime(void *arkode_mem, realtype *tcur)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetCurrentTime", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1393,7 +1414,7 @@ int arkGetTolScaleFactor(void *arkode_mem, realtype *tolsfact)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetTolScaleFactor", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1413,7 +1434,7 @@ int arkGetErrWeights(void *arkode_mem, N_Vector eweight)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetErrWeights", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1433,7 +1454,7 @@ int arkGetResWeights(void *arkode_mem, N_Vector rweight)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetResWeights", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1453,7 +1474,7 @@ int arkGetWorkSpace(void *arkode_mem, long int *lenrw, long int *leniw)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetWorkSpace", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1475,13 +1496,13 @@ int arkGetNumGEvals(void *arkode_mem, long int *ngevals)
   ARKodeMem ark_mem;
   ARKodeRootMem ark_root_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumGEvals", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
   ark_mem = (ARKodeMem) arkode_mem;
   if (ark_mem->root_mem == NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumGEvals", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1502,13 +1523,13 @@ int arkGetRootInfo(void *arkode_mem, int *rootsfound)
   ARKodeMem ark_mem;
   ARKodeRootMem ark_root_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetRootInfo", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
   ark_mem = (ARKodeMem) arkode_mem;
   if (ark_mem->root_mem == NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE",
                     "arkGetRootInfo", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1530,7 +1551,7 @@ int arkGetStepStats(void *arkode_mem, long int *nsteps,
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetStepStats", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1554,7 +1575,7 @@ int arkGetNumConstrFails(void *arkode_mem, long int *nconstrfails)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumConstrFails", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1574,7 +1595,7 @@ int arkGetNumExpSteps(void *arkode_mem, long int *nsteps)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumExpSteps", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1594,7 +1615,7 @@ int arkGetNumAccSteps(void *arkode_mem, long int *nsteps)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumAccSteps", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1614,7 +1635,7 @@ int arkGetNumErrTestFails(void *arkode_mem, long int *netfails)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumErrTestFails", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1635,7 +1656,7 @@ int arkGetNumStepSolveFails(void *arkode_mem, long int *nncfails)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetNumStepSolveFails", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1646,6 +1667,27 @@ int arkGetNumStepSolveFails(void *arkode_mem, long int *nncfails)
 }
 
 
+/*---------------------------------------------------------------
+  arkGetUserData:
+
+  Returns the user data pointer
+  ---------------------------------------------------------------*/
+int arkGetUserData(void *arkode_mem, void** user_data)
+{
+  ARKodeMem ark_mem;
+  if (arkode_mem==NULL) {
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
+                    "arkGetUserData", MSG_ARK_NO_MEM);
+    return(ARK_MEM_NULL);
+  }
+  ark_mem = (ARKodeMem) arkode_mem;
+
+  *user_data = ark_mem->user_data;
+
+  return(ARK_SUCCESS);
+}
+
+
 /*-----------------------------------------------------------------
   arkPrintAllStats
 
@@ -1658,7 +1700,7 @@ int arkPrintAllStats(void *arkode_mem, FILE *outfile, SUNOutputFormat fmt)
   ARKodeRootMem ark_root_mem;
 
   if (arkode_mem == NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkPrintAllStats", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1703,7 +1745,7 @@ int arkPrintAllStats(void *arkode_mem, FILE *outfile, SUNOutputFormat fmt)
     }
     break;
   default:
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode", "arkPrintAllStats",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE", "arkPrintAllStats",
                     "Invalid formatting option.");
     return(ARK_ILL_INPUT);
   }
@@ -1841,7 +1883,7 @@ char *arkGetReturnFlagName(long int flag)
 
 
 /*===============================================================
-  ARKode parameter output utility routine
+  ARKODE parameter output utility routine
   ===============================================================*/
 
 /*---------------------------------------------------------------
@@ -1852,13 +1894,13 @@ char *arkGetReturnFlagName(long int flag)
 int arkWriteParameters(ARKodeMem ark_mem, FILE *fp)
 {
   if (ark_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkWriteParameters", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
 
   /* print integrator parameters to file */
-  fprintf(fp, "ARKode solver parameters:\n");
+  fprintf(fp, "ARKODE solver parameters:\n");
   if (ark_mem->hmin != ZERO)
     fprintf(fp, "  Minimum step size = %" RSYM"\n",ark_mem->hmin);
   if (ark_mem->hmax_inv != ZERO)
@@ -1940,7 +1982,7 @@ int arkSetForcePass(void *arkode_mem, booleantype force_pass)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkSetForcePass", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -1961,7 +2003,7 @@ int arkGetLastKFlag(void *arkode_mem, int *last_kflag)
 {
   ARKodeMem ark_mem;
   if (arkode_mem==NULL) {
-    arkProcessError(NULL, ARK_MEM_NULL, "ARKode",
+    arkProcessError(NULL, ARK_MEM_NULL, "ARKODE",
                     "arkGetLastKFlag", MSG_ARK_NO_MEM);
     return(ARK_MEM_NULL);
   }
