@@ -2,7 +2,7 @@
  * Programmer(s): Alan C. Hindmarsh and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -716,6 +716,27 @@ int CVodeSetStopTime(void *cvode_mem, realtype tstop)
   return(CV_SUCCESS);
 }
 
+/*
+ * CVodeClearStopTime
+ *
+ * Disable the stop time.
+ */
+
+int CVodeClearStopTime(void *cvode_mem)
+{
+  CVodeMem cv_mem;
+
+  if (cvode_mem==NULL) {
+    cvProcessError(NULL, CV_MEM_NULL, "CVODES", "CVodeClearStopTime", MSGCV_NO_MEM);
+    return (CV_MEM_NULL);
+  }
+  cv_mem = (CVodeMem) cvode_mem;
+
+  cv_mem->cv_tstopset = SUNFALSE;
+
+  return(CV_SUCCESS);
+}
+
 /*
  * CVodeSetMaxErrTestFails
  *
@@ -2614,6 +2635,24 @@ int CVodePrintAllStats(void *cvode_mem, FILE *outfile, SUNOutputFormat fmt)
 
 /*-----------------------------------------------------------------*/
 
+int CVodeGetUserData(void *cvode_mem, void** user_data)
+{
+  CVodeMem cv_mem;
+
+  if (cvode_mem==NULL) {
+    cvProcessError(NULL, CV_MEM_NULL, "CVODES", "CVodeGetUserData", MSGCV_NO_MEM);
+    return(CV_MEM_NULL);
+  }
+
+  cv_mem = (CVodeMem) cvode_mem;
+
+  *user_data = cv_mem->cv_user_data;
+
+  return(CV_SUCCESS);
+}
+
+/*-----------------------------------------------------------------*/
+
 char *CVodeGetReturnFlagName(long int flag)
 {
   char *name;
